@@ -4,6 +4,7 @@ would be a good idea.
 """
 
 from lucenequerybuilder import Q
+from nose.tools import eq_
 
 def test_general():
     a = 'a'
@@ -71,3 +72,21 @@ def test_field_restrictions():
         pass
     else:
         raise AssertionError('Query allowed nested fields, which are invalid.')
+
+def test_fuzzy():
+    eq_(str(Q(fuzzy='fuzzi')), 'fuzzi~')
+
+    try:
+        Q(fuzzy='test fuzz')
+    except:
+        pass
+    else:
+        raise AssertionError("Fuzzy queries shouldn't have whitespace.")
+
+    eq_(str(Q(fuzzy=('fuzzi', .2))), 'fuzzi~0.200')
+    eq_(str(Q('field', fuzzy='fuzzi')), 'field:(fuzzi~)')
+
+def test_wildcard():
+    eq_(str(Q('lol*', wildcard=True)), 'lol*')
+    eq_(str(Q('field_with_*', 'some query')), 'field_with_*:("some query")')
+    eq_(str(Q('field_with_*', 'some*query', wildcard=True)), 'field_with_*:(some*query)')
